"""
    Slixmpp: The Slick XMPP Library
    Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
    This file is part of Slixmpp.

    See the file LICENSE for copying permission.
"""

from slixmpp.plugins.base import register_plugin

from slixmpp.plugins.xep_0153.stanza import VCardTempUpdate
from slixmpp.plugins.xep_0153.vcard_avatar import XEP_0153


register_plugin(XEP_0153)



"""
    Slixmpp: The Slick XMPP Library
    Copyright (C) 2010 Nathanael C. Fritz
    This file is part of Slixmpp.

    See the file LICENSE for copying permission.
"""

from slixmpp.plugins.base import register_plugin

from slixmpp.plugins.xep_0199.stanza import Ping
from slixmpp.plugins.xep_0199.ping import XEP_0199


register_plugin(XEP_0199)



"""
    Slixmpp: The Slick XMPP Library
    Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
    This file is part of Slixmpp.

    See the file LICENSE for copying permission.
"""

from slixmpp.plugins.base import register_plugin

from slixmpp.plugins.xep_0077.stanza import Register, RegisterFeature
from slixmpp.plugins.xep_0077.register import XEP_0077


register_plugin(XEP_0077)



"""
    slixmpp: The Slick XMPP Library
    Copyright (C) 2016 Emmanuel Gil Peyrot
    This file is part of slixmpp.

    See the file LICENSE for copying permission.
"""

from slixmpp.xmlstream import ElementBase

class Markable(ElementBase):
    name = 'markable'
    plugin_attrib = 'markable'
    namespace = 'urn:xmpp:chat-markers:0'

class Received(ElementBase):
    name = 'received'
    plugin_attrib = 'received'
    namespace = 'urn:xmpp:chat-markers:0'
    interfaces = {'id'}

class Displayed(ElementBase):
    name = 'displayed'
    plugin_attrib = 'displayed'
    namespace = 'urn:xmpp:chat-markers:0'
    interfaces = {'id'}

class Acknowledged(ElementBase):
    name = 'acknowledged'
    plugin_attrib = 'acknowledged'
    namespace = 'urn:xmpp:chat-markers:0'
    interfaces = {'id'}
